pub enum Error {
AddrParse(AddrParseError),
Internal(String),
InvalidArgument(String),
Io(Error),
StringParse(ParseError),
Values(ValueError),
}Expand description
Error represents the various errors which can come up while parsing command-line flags.
Variants
AddrParse(AddrParseError)
An error parsing an IP address.
Internal(String)
An internal unrecoverable error, usually due to some underlying library.
InvalidArgument(String)
Errors akin to EINVAL - essentially, an argument passed into a function was invalid in some way..
Io(Error)
An I/O error, generally encountered when interacting with the filesystem.
StringParse(ParseError)
An awkward hack; this error exists to use String’s FromStr impl, but this operation won’t actually ever fail.
Values(ValueError)
A flaggy_values error.